@@ -44,7 +44,7 @@ from update_checker import update_check
 from warnings import simplefilter, warn, warn_explicit
 
 
-__version__ = '2.1.4'
+__version__ = '2.1.5'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -57,7 +57,7 @@ PNG_HEADER = b'\x89\x50\x4e\x47\x0d\x0a\x1a\x0a'
 # Enable deprecation warnings
 simplefilter('default')
 
-# Compatability
+# Compatibility
 if six.PY3:
     CHR = chr
 else:
@@ -124,7 +124,9 @@ class Config(object):  # pylint: disable-msg=R0903, R0924
                  'saved':               'saved/',
                  'search':              'r/%s/search/',
                  'search_reddit_names': 'api/search_reddit_names/',
+                 'select_flair':        'api/selectflair/',
                  'sent':                'message/sent/',
+                 'sticky_submission':   'api/set_subreddit_sticky/',
                  'site_admin':          'api/site_admin/',
                  'spam':                'r/%s/about/spam/',
                  'stylesheet':          'r/%s/about/stylesheet/',
@@ -195,7 +197,8 @@ class Config(object):  # pylint: disable-msg=R0903, R0924
         self.domain = obj['domain']
         self.output_chars_limit = int(obj['output_chars_limit'])
         self.log_requests = int(obj['log_requests'])
-        self.http_proxy = obj.get('http_proxy') or None
+        self.http_proxy = (obj.get('http_proxy') or os.getenv('http_proxy') or
+                           None)
         # We use `get(...) or None` because `get` may return an empty string
         self.client_id = obj.get('oauth_client_id') or None
         self.client_secret = obj.get('oauth_client_secret') or None
@@ -251,7 +254,7 @@ class BaseReddit(object):
 
         The user_agent is how your application identifies itself. Read the
         official API guidelines for user_agents
-        https://github.com/reddit/reddit/wiki/API.  Applications using default
+        https://github.com/reddit/reddit/wiki/API. Applications using default
         user_agents such as "Python/urllib" are drastically limited.
 
         site_name allows you to specify which reddit you want to connect to.
@@ -926,12 +929,15 @@ class UnauthenticatedReddit(BaseReddit):
                 raise
         return result
 
-    def search(self, query, subreddit=None, sort=None, *args, **kwargs):
+    def search(self, query, subreddit=None, sort=None, syntax=None,
+               period=None, *args, **kwargs):
         """Return a generator for submissions that match the search query.
 
         :param query: The query string to search for.
         :param subreddit: Limit search results to the subreddit if provided.
         :param sort: The sort order of the results.
+        :param syntax: The syntax of the search query.
+        :param period: The time period of the results.
 
         The additional parameters are passed directly into
         :meth:`.get_content`. Note: the `url` and `param` parameters cannot be
@@ -944,6 +950,10 @@ class UnauthenticatedReddit(BaseReddit):
         params = {'q': query}
         if sort:
             params['sort'] = sort
+        if syntax:
+            params['syntax'] = syntax
+        if period:
+            params['t'] = period
         if subreddit:
             params['restrict_sr'] = 'on'
             url = self.config['search'] % subreddit
@@ -1047,7 +1057,7 @@ class AuthenticatedReddit(OAuth2Reddit, UnauthenticatedReddit):
         """
         data = {'content': content,
                 'page': page,
-                'r':  six.text_type(subreddit),
+                'r': six.text_type(subreddit),
                 'reason': reason}
         return self.request_json(self.config['wiki_edit'], data=data)
 
@@ -1144,6 +1154,40 @@ class AuthenticatedReddit(OAuth2Reddit, UnauthenticatedReddit):
             self.set_access_credentials(**response)
         return response
 
+    @decorators.restrict_access(scope=None, login=True)
+    def select_flair(self, item, flair_template_id='', flair_text=''):
+        """Select user flair or link flair on subreddits.
+
+        This can only be used for assigning your own name flair or link flair
+        on your own submissions. For assigning other's flairs using moderator
+        access, check :meth:`.set_flair`
+
+        :param item: A string, Subreddit object (for user flair), or
+            Submission object (for link flair). If item is a string it will be
+            treated as the name of a Subreddit.
+        :param flair_template_id: 36 characters id found in the HTML of a
+            flair selector.
+        :param flair_text: A String containing the custom flair text.
+            Used on subreddits that allow it.
+
+        :returns: The json response from the server.
+
+        """
+        data = {'flair_template_id': flair_template_id or '',
+                'text':              flair_text or ''}
+        if isinstance(item, objects.Submission):
+            # Link flair
+            data['link'] = item.fullname
+            evict = item.permalink
+        else:
+            # User flair
+            data['name'] = self.user.name
+            data['r'] = six.text_type(item)
+            evict = self.config['flairlist'] % six.text_type(item)
+        response = self.request_json(self.config['select_flair'], data=data)
+        self.evict(evict)
+        return response
+
     @decorators.require_oauth
     def set_access_credentials(self, scope, access_token, refresh_token=None,
                                update_user=True):
@@ -1180,7 +1224,7 @@ class ModConfigMixin(AuthenticatedReddit):
 
     """
 
-    @decorators.restrict_access(scope='modconfig')
+    @decorators.restrict_access(scope='modconfig', mod=False, login=True)
     def create_subreddit(self, name, title, description='', language='en',
                          subreddit_type='public', content_options='any',
                          over_18=False, default_set=True, show_media=False,
@@ -1243,7 +1287,7 @@ class ModConfigMixin(AuthenticatedReddit):
                      public_traffic=False, **kwargs):
         """Set the settings for the given subreddit.
 
-        :param subreddit: Must be  a subreddit object.
+        :param subreddit: Must be a subreddit object.
         :returns: The json response from the server.
 
         """
@@ -1304,7 +1348,7 @@ class ModConfigMixin(AuthenticatedReddit):
         :param image_path: A path to the jpg or png image you want to upload.
         :param name: The name to provide the image. When None the name will be
             filename less any extension.
-        :param header: When true, upload the image as the subreddit header.
+        :param header: When True, upload the image as the subreddit header.
         :returns: True when the upload was successful. False otherwise. Note
             this is subject to change.
 
@@ -1438,7 +1482,7 @@ class ModFlairMixin(AuthenticatedReddit):
                 'name': six.text_type(user)}
         return self.request_json(self.config['deleteflair'], data=data)
 
-    @decorators.restrict_access(scope='modflair')
+    @decorators.restrict_access(scope='modflair', mod=False, login=False)
     def get_flair_list(self, subreddit, *args, **kwargs):
         """Return a get_content generator of flair mappings.
 
@@ -1580,7 +1624,7 @@ class ModOnlyMixin(AuthenticatedReddit):
 
     @decorators.restrict_access(scope=None, mod=True)
     def get_mod_queue(self, subreddit='mod', *args, **kwargs):
-        """Return a get_content_generator for the  moderator queue.
+        """Return a get_content_generator for the moderator queue.
 
         :param subreddit: Either a Subreddit object or the name of the
             subreddit to return the flair list for. Defaults to `mod` which
@@ -1623,7 +1667,9 @@ class ModOnlyMixin(AuthenticatedReddit):
         return self.get_content(self.config['spam'] % six.text_type(subreddit),
                                 *args, **kwargs)
 
-    @decorators.restrict_access(scope=None, mod=True)
+    # OAuth scope modconfig for this method cannot be added until there has
+    # been an upstream change. See issue #174. Then the restriction will be
+    # @restrict_access('modconfig', mod=False, login=False)
     def get_stylesheet(self, subreddit):
         """Return the stylesheet and images for the given subreddit."""
         return self.request_json(self.config['stylesheet'] %
@@ -1764,9 +1810,9 @@ class PrivateMessagesMixin(AuthenticatedReddit):
                    **kwargs):
         """Return a get_content generator for unread messages.
 
-        :param unset_has_mail: When true, clear the has_mail flag (orangered)
+        :param unset_has_mail: When True, clear the has_mail flag (orangered)
             for the user.
-        :param update_user: If both `unset_has_mail` and `update user` is true,
+        :param update_user: If both `unset_has_mail` and `update user` is True,
             set the `has_mail` attribute of the logged-in user to False.
 
         The additional parameters are passed directly into
@@ -1900,7 +1946,7 @@ class SubscribeMixin(AuthenticatedReddit):
         """Subscribe to the given subreddit.
 
         :param subreddit: Either the subreddit name or a subreddit object.
-        :param unsubscribe: When true, unsubscribe.
+        :param unsubscribe: When True, unsubscribe.
         :returns: The json response from the server.
 
         """
