@@ -103,7 +103,7 @@ class RedditContentObject(object):
         return retval
 
     def _get_json_dict(self):
-        # (disbled for entire function) pylint: disable-msg=W0212
+        # (disabled for entire function) pylint: disable-msg=W0212
 
         # OAuth handling needs to be special cased here. For instance, the user
         # might be calling a method on a Subreddit object that requires first
@@ -622,7 +622,7 @@ class Redditor(Messageable, Refreshable):
     def __cmp__(self, other):
         """Compare two redditors based on the lowercase of their name.
 
-        :returns: negative, 0, or positive depending on the comparision.
+        :returns: negative, 0, or positive depending on the comparison.
 
         """
         return cmp(self.name.lower(), other.name.lower())
@@ -928,6 +928,31 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
         """
         return urljoin(self.reddit_session.config.short_domain, self.id)
 
+    @restrict_access(scope='modposts')
+    def sticky(self):
+        """Sticky a post in its subreddit.
+
+        If there is already a stickied post in the concerned subreddit then it
+        will be unstickied.
+
+        :returns: The json response from the server
+
+        """
+        url = self.reddit_session.config['sticky_submission']
+        data = {'id': self.fullname, 'state': True}
+        return self.reddit_session.request_json(url, data=data)
+
+    @restrict_access(scope='modposts')
+    def unsticky(self):
+        """Unsticky this post.
+
+        :returns: The json response from the server
+
+        """
+        url = self.reddit_session.config['sticky_submission']
+        data = {'id': self.fullname, 'state': False}
+        return self.reddit_session.request_json(url, data=data)
+
 
 class Subreddit(Messageable, Refreshable):
 
@@ -960,6 +985,7 @@ class Subreddit(Messageable, Refreshable):
                 ('get_wiki_page', UR),
                 ('get_wiki_pages', UR),
                 ('search', UR),
+                ('select_flair', AR),
                 ('set_flair', MFMix),
                 ('set_flair_csv', MFMix),
                 ('set_settings', MCMix),
@@ -1023,7 +1049,7 @@ class Subreddit(Messageable, Refreshable):
     def __cmp__(self, other):
         """Compare two subreddits based on the lowercase of their name.
 
-        :returns: negative, 0, or positive depending on the comparision.
+        :returns: negative, 0, or positive depending on the comparison.
 
         """
         return cmp(self.display_name.lower(), other.display_name.lower())
@@ -1031,7 +1057,7 @@ class Subreddit(Messageable, Refreshable):
     def __init__(self, reddit_session, subreddit_name=None, json_dict=None,
                  fetch=False):
         # Special case for when my_subreddits is called as no name is returned
-        # so we have to extract the name from the URL.  The URLs are returned
+        # so we have to extract the name from the URL. The URLs are returned
         # as: /r/reddit_name/
         if not subreddit_name:
             subreddit_name = json_dict['url'].split('/')[2]
