@@ -242,7 +242,7 @@ class BasicTest(unittest.TestCase, BasicHelper):
     def test_get_comments_gilded(self):
         gilded_comments = self.r.get_comments('all', gilded_only=True)
         for comment in gilded_comments:
-            self.assertTrue(comment.gilded >= 0)
+            self.assertTrue(comment.gilded > 0)
 
     @reddit_only
     def test_get_controversial(self):
@@ -323,6 +323,23 @@ class BasicTest(unittest.TestCase, BasicHelper):
     def test_search(self):
         self.assertTrue(len(list(self.r.search('test'))) > 0)
 
+    @reddit_only
+    def test_search_with_syntax(self):
+        # Searching with timestamps only possible with cloudsearch
+        no_syntax = self.r.search("timestamp:1354348800..1354671600",
+                                  subreddit=self.sr)
+        self.assertFalse(list(no_syntax))
+        with_syntax = self.r.search("timestamp:1354348800..1354671600",
+                                    subreddit=self.sr, syntax='cloudsearch')
+        self.assertTrue(list(with_syntax))
+
+    @reddit_only
+    def test_search_with_time_window(self):
+        submissions = len(list(self.r.search('test', subreddit=self.sr,
+                                             period='week', limit=1000)))
+        self.assertTrue(submissions > 0)
+        self.assertTrue(submissions < 1000)
+
     def test_search_reddit_names(self):
         self.assertTrue(len(self.r.search_reddit_names('reddit')) > 0)
 
@@ -371,6 +388,97 @@ class CacheTest(unittest.TestCase, AuthenticatedHelper):
         self.assertNotEqual(submission.likes, same_submission.likes)
 
 
+class EmbedTextTest(unittest.TestCase):
+    embed_text = "Hello"
+
+    def test_no_docstring(self):
+        new_doc = decorators._embed_text(None, self.embed_text)
+        self.assertEqual(new_doc, self.embed_text)
+
+    def test_one_liner(self):
+        new_doc = decorators._embed_text("Returns something cool",
+                                         self.embed_text)
+        self.assertEqual(new_doc,
+                         "Returns something cool\n\n" + self.embed_text)
+
+    def test_multi_liner(self):
+        doc = """Jiggers the bar
+
+              Only run if foo is instantiated.
+
+              """
+        new_doc = decorators._embed_text(doc, self.embed_text)
+        self.assertEqual(new_doc, doc + self.embed_text + "\n\n")
+
+    def test_single_plus_params(self):
+        doc = """Jiggers the bar
+
+              :params foo: Self explanatory.
+
+              """
+        expected_doc = """Jiggers the bar
+
+              {}
+
+              :params foo: Self explanatory.
+
+              """.format(self.embed_text)
+        new_doc = decorators._embed_text(doc, self.embed_text)
+        self.assertEqual(new_doc, expected_doc)
+
+    def test_multi_plus_params(self):
+        doc = """Jiggers the bar
+
+              Jolly importment.
+
+              :params foo: Self explanatory.
+              :returns: The jiggered bar.
+
+              """
+        expected_doc = """Jiggers the bar
+
+              Jolly importment.
+
+              {}
+
+              :params foo: Self explanatory.
+              :returns: The jiggered bar.
+
+              """.format(self.embed_text)
+        new_doc = decorators._embed_text(doc, self.embed_text)
+        self.assertEqual(new_doc, expected_doc)
+
+    def test_additional_params(self):
+        doc = """Jiggers the bar
+
+              Jolly important.
+
+              :params foo: Self explanatory.
+              :returns: The jiggered bar.
+
+              The additional parameters are passed directly into
+              :meth:`.get_content`. Note: the `url` parameter cannot be
+              altered.
+
+              """
+        expected_doc = """Jiggers the bar
+
+              Jolly important.
+
+              {}
+
+              :params foo: Self explanatory.
+              :returns: The jiggered bar.
+
+              The additional parameters are passed directly into
+              :meth:`.get_content`. Note: the `url` parameter cannot be
+              altered.
+
+              """.format(self.embed_text)
+        new_doc = decorators._embed_text(doc, self.embed_text)
+        self.assertEqual(new_doc, expected_doc)
+
+
 class EncodingTest(unittest.TestCase, AuthenticatedHelper):
     def setUp(self):
         self.configure()
@@ -542,7 +650,7 @@ class FlairTest(unittest.TestCase, AuthenticatedHelper):
         self.assertEqual(sub.link_flair_text, flair_text)
 
     def test_add_link_flair_through_submission(self):
-        flair_text = 'Falir: %s' % uuid.uuid4()
+        flair_text = 'Flair: %s' % uuid.uuid4()
         sub = six_next(self.subreddit.get_new())
         sub.set_flair(flair_text)
         sub = self.r.get_submission(sub.permalink)
@@ -624,6 +732,108 @@ class FlairTest(unittest.TestCase, AuthenticatedHelper):
                           self.subreddit.set_flair_csv, flair_mapping)
 
 
+class FlairSelectTest(unittest.TestCase, AuthenticatedHelper):
+    def setUp(self):
+        self.configure()
+        self.subreddit = self.r.get_subreddit(self.priv_sr)
+        self.user_flair_templates = {
+            'UserCssClassOne':  ('21e00aae-09cf-11e3-a4f1-12313d281541',
+                                 'default_user_flair_text_one'),
+            'UserCssClassTwo':  ('2f6504c2-09cf-11e3-9d8d-12313d281541',
+                                 'default_user_flair_text_two')
+        }
+        self.link_flair_templates = {
+            'LinkCssClassOne':  ('36a573c0-09cf-11e3-b5f7-12313d096169',
+                                 'default_link_flair_text_one'),
+            'LinkCssClassTwo':  ('3b73f516-09cf-11e3-9a71-12313d281541',
+                                 'default_link_flair_text_two')
+        }
+
+    def get_different_user_flair_class(self):
+        flair = self.r.get_flair(self.subreddit, self.r.user)
+        if flair == self.user_flair_templates.keys()[0]:
+            different_flair = self.user_flair_templates.keys()[1]
+        else:
+            different_flair = self.user_flair_templates.keys()[0]
+        return different_flair
+
+    def get_different_link_flair_class(self, submission):
+        flair = submission.link_flair_css_class
+        if flair == self.link_flair_templates.keys()[0]:
+            different_flair = self.link_flair_templates.keys()[1]
+        else:
+            different_flair = self.link_flair_templates.keys()[0]
+        return different_flair
+
+    def test_select_user_flair(self):
+        flair_class = self.get_different_user_flair_class()
+        flair_id = self.user_flair_templates[flair_class][0]
+        flair_default_text = self.user_flair_templates[flair_class][1]
+        self.r.select_flair(item=self.subreddit,
+                            flair_template_id=flair_id)
+        flair = self.r.get_flair(self.subreddit, self.r.user)
+        self.assertEqual(flair['flair_text'], flair_default_text)
+        self.assertEqual(flair['flair_css_class'], flair_class)
+
+    def test_select_link_flair(self):
+        sub = six_next(self.subreddit.get_new())
+        flair_class = self.get_different_link_flair_class(sub)
+        flair_id = self.link_flair_templates[flair_class][0]
+        flair_default_text = self.link_flair_templates[flair_class][1]
+        self.r.select_flair(item=sub,
+                            flair_template_id=flair_id)
+        sub = self.r.get_submission(sub.permalink)
+        self.assertEqual(sub.link_flair_text, flair_default_text)
+        self.assertEqual(sub.link_flair_css_class, flair_class)
+
+    def test_select_user_flair_custom_text(self):
+        flair_class = self.get_different_user_flair_class()
+        flair_id = self.user_flair_templates[flair_class][0]
+        flair_text = 'Flair: %s' % uuid.uuid4()
+        self.r.select_flair(item=self.subreddit,
+                            flair_template_id=flair_id,
+                            flair_text=flair_text)
+        flair = self.r.get_flair(self.subreddit, self.r.user)
+        self.assertEqual(flair['flair_text'], flair_text)
+        self.assertEqual(flair['flair_css_class'], flair_class)
+
+    def test_select_link_flair_custom_text(self):
+        sub = six_next(self.subreddit.get_new())
+        flair_class = self.get_different_link_flair_class(sub)
+        flair_id = self.link_flair_templates[flair_class][0]
+        flair_text = 'Flair: %s' % uuid.uuid4()
+        self.r.select_flair(item=sub,
+                            flair_template_id=flair_id,
+                            flair_text=flair_text)
+        sub = self.r.get_submission(sub.permalink)
+        self.assertEqual(sub.link_flair_text, flair_text)
+        self.assertEqual(sub.link_flair_css_class, flair_class)
+
+    def test_select_user_flair_remove(self):
+        flair = self.r.get_flair(self.subreddit, self.r.user)
+        if flair['flair_css_class'] is None:
+            flair_class = self.get_different_user_flair_class()
+            flair_id = self.user_flair_templates[flair_class][0]
+            self.r.select_flair(item=self.subreddit,
+                                flair_template_id=flair_id)
+        self.r.select_flair(item=self.subreddit)
+        flair = self.r.get_flair(self.subreddit, self.r.user)
+        self.assertEqual(flair['flair_text'], None)
+        self.assertEqual(flair['flair_css_class'], None)
+
+    def test_select_link_flair_remove(self):
+        sub = six_next(self.subreddit.get_new())
+        if sub.link_flair_css_class is None:
+            flair_class = self.get_different_link_flair_class(sub)
+            flair_id = self.link_flair_templates[flair_class][0]
+            self.r.select_flair(item=sub,
+                                flair_template_id=flair_id)
+        self.r.select_flair(item=sub)
+        sub = self.r.get_submission(sub.permalink)
+        self.assertEqual(sub.link_flair_text, None)
+        self.assertEqual(sub.link_flair_css_class, None)
+
+
 class FlairTemplateTest(unittest.TestCase, AuthenticatedHelper):
     def setUp(self):
         self.configure()
@@ -663,8 +873,8 @@ class ImageTests(unittest.TestCase, AuthenticatedHelper):
         self.assertNotEqual(images, updated_images)
 
     def test_delete_invalid_image(self):
-        # TODO: Patch reddit to return error when this fails
-        self.subreddit.delete_image(name='invalid_image_name')
+        self.assertRaises(errors.BadCSSName,
+                          self.subreddit.delete_image, 'invalid_image_name')
 
     def test_delete_invalid_params(self):
         self.assertRaises(TypeError, self.subreddit.delete_image, name='Foo',
@@ -1247,6 +1457,10 @@ class SettingsTest(unittest.TestCase, AuthenticatedHelper):
         self.assertEqual(stylesheet,
                          self.subreddit.get_stylesheet()['stylesheet'])
 
+    def test_set_stylesheet_invalid_css(self):
+        self.assertRaises(errors.BadCSS, self.subreddit.set_stylesheet,
+                          'INVALID CSS')
+
     def test_update_settings_description(self):
         self.maxDiff = None
         settings = self.subreddit.get_settings()
@@ -1324,7 +1538,8 @@ class SubmissionEditTest(unittest.TestCase, AuthenticatedHelper):
             self.assertFalse(submission.distinguished)
 
         self.disable_cache()
-        submission = six_next(self.subreddit.get_top())
+        sub_id = self.submission_edit_id
+        submission = self.r.get_submission(submission_id=sub_id)
         if submission.distinguished:
             verify_undistinguish(submission)
             verify_distinguish(submission)
@@ -1474,6 +1689,28 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
             self.assertRaises(errors.ClientException, getattr, submission,
                               'short_link')
 
+    def test_sticky_unsticky(self):
+        def verify_sticky():
+            submission.sticky()
+            submission.refresh()
+            self.assertTrue(submission.stickied)
+
+        def verify_unsticky():
+            submission.unsticky()
+            submission.refresh()
+            self.assertFalse(submission.stickied)
+
+        self.disable_cache()
+        submission_id = self.submission_edit_id
+        submission = self.r.get_submission(submission_id=submission_id)
+
+        if submission.stickied:
+            verify_unsticky()
+            verify_sticky()
+        else:
+            verify_sticky()
+            verify_unsticky()
+
     def test_unhide(self):
         self.disable_cache()
         found = None
